cemento.utils package — CEMENTO 0.8.5 documentation

Skip to main content
`Ctrl`+`K`

# cemento.utils package

## Submodules

## cemento.utils.io module

cemento.utils.io.get_default_defaults_folder() → Path

cemento.utils.io.get_default_path(rel_path: str | Path) → Path

cemento.utils.io.get_default_prefixes_file() → Path

cemento.utils.io.get_default_references_folder() → Path

## cemento.utils.utils module

cemento.utils.utils.aggregate_defaultdict(acc: defaultdict[list], item: tuple[any, any]) → defaultdict[list]

cemento.utils.utils.filter_graph(graph: DiGraph, data_filter: Callable[[dict[str, any]], bool]) → DiGraph

cemento.utils.utils.fst(x: tuple[any, any]) → any

cemento.utils.utils.get_abbrev_term(term: str, is_predicate=False, default_prefix='mds') → tuple[str, str]

cemento.utils.utils.remove_term_names(term: str) → str

cemento.utils.utils.snd(x: tuple[any, any]) → any

cemento.utils.utils.trd(x: tuple[any, any, any]) → any

## Module contents